import { parse } from "@babel/parser";
import traverse from "@babel/traverse";
import { printNodeWithBrackets } from "./printNodeWithBrackets.js";
const getParseOptions = (isJsx) => ({
  allowImportExportEverywhere: true,
  allowNewTargetOutsideFunction: true,
  allowReturnOutsideFunction: true,
  allowSuperOutsideMethod: true,
  allowUndeclaredExports: true,
  errorRecovery: true,
  plugins: [
    "doExpressions",
    "exportDefaultFrom",
    "functionBind",
    "functionSent",
    "throwExpressions",
    "partialApplication",
    "decorators",
    "decimal",
    "moduleBlocks",
    "asyncDoExpressions",
    "regexpUnicodeSets",
    "destructuringPrivate",
    "decoratorAutoAccessors",
    "importReflection",
    "explicitResourceManagement",
    "decoratorAutoAccessors",
    "typescript",
    ...isJsx ? ["jsx"] : [],
    ["importAttributes", { deprecatedAssertSyntax: true }]
  ],
  ranges: true,
  sourceType: "module"
});
function preprocess(code, options) {
  const ast = parse(code, getParseOptions(/(?:js|x)$/.test(options.filepath)));
  const collectedNodes = [];
  function collector({ node }) {
    collectedNodes.push(node);
  }
  (traverse.default || traverse)(ast, {
    DoWhileStatement: collector,
    ForInStatement: collector,
    ForOfStatement: collector,
    ForStatement: collector,
    IfStatement: collector,
    WhileStatement: collector,
    noScope: true
  });
  let output = "";
  let lastEnd = 0;
  for (const collectedNode of collectedNodes) {
    output += code.slice(lastEnd, collectedNode.start);
    output += printNodeWithBrackets(code, collectedNode);
    lastEnd = collectedNode.end;
  }
  return output + code.slice(lastEnd);
}
export {
  preprocess
};
//# sourceMappingURL=preprocess.js.map